==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/zh_TW.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "伺服器對伺服器共享在這台伺服器上面並未啟用",
    "The mountpoint name contains invalid characters." : "掛載的名稱含有不合法的字元",
    "Not allowed to create a federated share with the same user server" : "不允許在同一個使用者伺服器建立聯盟式分享",
    "Invalid or untrusted SSL certificate" : "無效或是不信任的 SSL憑證",
    "Could not authenticate to remote share, password might be wrong" : "無法驗證遠端分享，可能是密碼錯誤",
    "Storage not valid" : "儲存空間無法使用",
    "Couldn't add remote share" : "無法加入遠端分享",
    "Shared with you" : "與您分享",
    "Shared with others" : "與其他人分享",
    "Shared by link" : "由連結分享",
    "Uploading..." : "上傳中…",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要加入來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share" : "遠端分享",
    "Remote share password" : "遠端分享密碼",
    "Cancel" : "取消",
    "Add remote share" : "加入遠端分享",
    "You can upload into this folder" : "你可以上傳內容到此資料夾",
    "No ownCloud installation (7 or higher) found at {remote}" : "沒有在 {remote} 找到 ownCloud (本版7 或 更新版)",
    "Invalid ownCloud url" : "無效的 ownCloud URL",
    "Share" : "分享",
    "No expiration date set" : "沒有設定到期日",
    "Shared by" : "分享自",
    "Sharing" : "分享",
    "Share API is disabled" : "分享 API 已停用",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID，分享不存在",
    "Could not delete share" : "可能不能刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤路徑，檔案/資料夾不存在",
    "Please specify a valid user" : "請指定正確的使用者",
    "Group sharing is disabled by the administrator" : "群組分享已被管理者停用",
    "Please specify a valid group" : "請指定正確的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理者停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理者停用",
    "Public upload is only possible for publicly shared folders" : "公開上傳只可能給公用分享資料夾",
    "Invalid date, date format must be YYYY-MM-DD" : "無效日期，日期格式必須為 YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "分享 %s 失敗因為後台不允許從類型 %s 來分享",
    "Unknown share type" : "未知分享類型",
    "Not a directory" : "不是目錄",
    "Could not lock path" : "無法鎖定路徑",
    "Can't change permissions for public share links" : "無法變更公開分享連結的權限",
    "Wrong or no update parameter given" : "錯誤或沒有更新參數設定",
    "Cannot increase permissions" : "無法增加權限",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
    "A public shared file or folder was <strong>downloaded</strong>" : "共享檔案或目錄已被 <strong>下載</strong>",
    "You received a new remote share %2$s from %1$s" : "您收到了一個遠端分享 %2$s 來自於 %1$s",
    "You received a new remote share from %s" : "您收到了一個遠端分享來自於 %s",
    "%1$s accepted remote share %2$s" : "%1$s 接受了遠端分享 %2$s",
    "%1$s declined remote share %2$s" : "%1$s 拒絕了遠端分享 %2$s",
    "%1$s unshared %2$s from you" : "%1$s 取消與你分享 %2$s",
    "Public shared folder %1$s was downloaded" : "共享資料夾 %1$s 已被下載",
    "Public shared file %1$s was downloaded" : "共享檔案 %1$s 已被下載",
    "You shared %1$s with %2$s" : "您與 %2$s 分享了 %1$s",
    "%2$s shared %1$s with %3$s" : "%2$s 與 %3$s 分享了 %1$s",
    "You removed the share of %2$s for %1$s" : "您移除了分享 %2$s 給 %1$s",
    "You shared %1$s with group %2$s" : "您與 %2$s 群組分享了 %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s 與群組 %3$s 分享了 %1$s",
    "%2$s shared %1$s via link" : "%2$s 透過連結分享了 %1$s ",
    "You shared %1$s via link" : "您以連結分享了 %1$s",
    "%2$s shared %1$s with you" : "%2$s 與您分享了 %1$s",
    "Downloaded via public link" : "透過公用連結下載",
    "Shared with %2$s" : "與 %2$s 分享",
    "Shared with %3$s by %2$s" : "透過 %2$s 與 %3$s 分享",
    "Shared with group %2$s" : "與群組 %2$s 分享",
    "Shared with group %3$s by %2$s" : "透過 %2$s 與群組 %3$s 分享",
    "Shared via link by %2$s" : "%2$s 透過連結分享",
    "Shared via public link" : "透過公用連結分享",
    "Shared by %2$s" : "由 %2$s 分享",
    "Shares" : "分享",
    "This share is password-protected" : "這個分享有密碼保護",
    "The password is wrong. Try again." : "請檢查您的密碼並再試一次",
    "Password" : "密碼",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Add to your ownCloud" : "加入到你的 ownCloud",
    "Download" : "下載",
    "Download %s" : "下載 %s",
    "Direct link" : "直接連結",
    "Pending" : "等候中",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "Declined" : "已拒絕",
    "Couldn't send mail to following recipient(s): %s " : "無法發送郵件給以下人員：%s"
},
"nplurals=1; plural=0;");

==> owncloud-10.4.1.zip: owncloud/apps/files_sharing/l10n/zh_TW.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "伺服器對伺服器共享在這台伺服器上面並未啟用",
    "The mountpoint name contains invalid characters." : "掛載的名稱含有不合法的字元",
    "Not allowed to create a federated share with the same user server" : "不允許在同一個使用者伺服器建立聯盟式分享",
    "Invalid or untrusted SSL certificate" : "無效或是不信任的 SSL憑證",
    "Could not authenticate to remote share, password might be wrong" : "無法驗證遠端分享，可能是密碼錯誤",
    "Storage not valid" : "儲存空間無法使用",
    "Couldn't add remote share" : "無法加入遠端分享",
    "Shared with you" : "與您分享",
    "Shared with others" : "與其他人分享",
    "Shared by link" : "由連結分享",
    "Uploading..." : "上傳中…",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要加入來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share" : "遠端分享",
    "Remote share password" : "遠端分享密碼",
    "Cancel" : "取消",
    "Add remote share" : "加入遠端分享",
    "You can upload into this folder" : "你可以上傳內容到此資料夾",
    "No ownCloud installation (7 or higher) found at {remote}" : "沒有在 {remote} 找到 ownCloud (本版7 或 更新版)",
    "Invalid ownCloud url" : "無效的 ownCloud URL",
    "Share" : "分享",
    "No expiration date set" : "沒有設定到期日",
    "Declined" : "已拒絕",
    "Pending" : "等候中",
    "Shared by" : "分享自",
    "Sharing" : "分享",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
    "A public shared file or folder was <strong>downloaded</strong>" : "共享檔案或目錄已被 <strong>下載</strong>",
    "You received a new remote share %2$s from %1$s" : "您收到了一個遠端分享 %2$s 來自於 %1$s",
    "You received a new remote share from %s" : "您收到了一個遠端分享來自於 %s",
    "%1$s accepted remote share %2$s" : "%1$s 接受了遠端分享 %2$s",
    "%1$s declined remote share %2$s" : "%1$s 拒絕了遠端分享 %2$s",
    "%1$s unshared %2$s from you" : "%1$s 取消與你分享 %2$s",
    "Public shared folder %1$s was downloaded" : "共享資料夾 %1$s 已被下載",
    "Public shared file %1$s was downloaded" : "共享檔案 %1$s 已被下載",
    "You shared %1$s with %2$s" : "您與 %2$s 分享了 %1$s",
    "%2$s shared %1$s with %3$s" : "%2$s 與 %3$s 分享了 %1$s",
    "You removed the share of %2$s for %1$s" : "您移除了分享 %2$s 給 %1$s",
    "You shared %1$s with group %2$s" : "您與 %2$s 群組分享了 %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s 與群組 %3$s 分享了 %1$s",
    "%2$s shared %1$s via link" : "%2$s 透過連結分享了 %1$s ",
    "You shared %1$s via link" : "您以連結分享了 %1$s",
    "%2$s shared %1$s with you" : "%2$s 與您分享了 %1$s",
    "Downloaded via public link" : "透過公用連結下載",
    "Shared with %2$s" : "與 %2$s 分享",
    "Shared with %3$s by %2$s" : "透過 %2$s 與 %3$s 分享",
    "Shared with group %2$s" : "與群組 %2$s 分享",
    "Shared with group %3$s by %2$s" : "透過 %2$s 與群組 %3$s 分享",
    "Shared via link by %2$s" : "%2$s 透過連結分享",
    "Shared via public link" : "透過公用連結分享",
    "Shared by %2$s" : "由 %2$s 分享",
    "Shares" : "分享",
    "Couldn't send mail to following recipient(s): %s " : "無法發送郵件給以下人員：%s",
    "Share API is disabled" : "分享 API 已停用",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID，分享不存在",
    "Could not delete share" : "可能不能刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤路徑，檔案/資料夾不存在",
    "Invalid date, date format must be YYYY-MM-DD" : "無效日期，日期格式必須為 YYYY-MM-DD",
    "Please specify a valid user" : "請指定正確的使用者",
    "Group sharing is disabled by the administrator" : "群組分享已被管理者停用",
    "Please specify a valid group" : "請指定正確的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理者停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理者停用",
    "Public upload is only possible for publicly shared folders" : "公開上傳只可能給公用分享資料夾",
    "Sharing %s failed because the back end does not allow shares from type %s" : "分享 %s 失敗因為後台不允許從類型 %s 來分享",
    "Unknown share type" : "未知分享類型",
    "Not a directory" : "不是目錄",
    "Could not lock path" : "無法鎖定路徑",
    "Can't change permissions for public share links" : "無法變更公開分享連結的權限",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "This share is password-protected" : "這個分享有密碼保護",
    "The password is wrong. Try again." : "請檢查您的密碼並再試一次",
    "Password" : "密碼",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Download" : "下載",
    "Download %s" : "下載 %s",
    "Direct link" : "直接連結"
},
"nplurals=1; plural=0;");
